 /*
 *    PIC C Compiler (CCS)
 *
 *    @section Author
 *
 *    microchipotle.com
 *
 */

#include <stdint.h>

#define AHT10_I2CADDR 0x38   // Direccion
#define AHT10_CALIBRATE 0xE1 // Calibracin
#define AHT10_TRIGGER 0xAC   // Trigger Lectura
#define AHT10_SOFTRESET 0xBA // Restablecer
#define AHT10_BUSY 0x80      // Estado ocupado
#define AHT10_CALIBRATED 0x08 //Estado calibrado
#define AHT10_DATA0 0x33 //Dato 0
#define AHT10_DATA1 0x00 //Dato 1

void AHT10_begin()
{
   i2c_start(AHT10_stream);
   i2c_write(AHT10_stream, AHT10_I2CADDR << 1);    
   i2c_write(AHT10_stream, AHT10_SOFTRESET);    
   i2c_stop(AHT10_stream);
   
   delay_ms(20);
   
   i2c_start(AHT10_stream);        
   i2c_write(AHT10_stream, AHT10_I2CADDR << 1); //Direccion de escritura      
   i2c_write(AHT10_stream, AHT10_CALIBRATE);     
   i2c_write(AHT10_stream, 0x08);    
   i2c_write(AHT10_stream, 0x00);    
   i2c_stop(AHT10_stream);   
   
    delay_ms(20);   
}
    
void AHT10_Read(float *hum, float *temp)
{ 
   uint8_t buffer[6];
   do{  
      i2c_start(AHT10_stream);
      i2c_write(AHT10_stream, AHT10_I2CADDR << 1);     
      i2c_write(AHT10_stream, AHT10_TRIGGER);  
      i2c_write(AHT10_stream, AHT10_DATA0);  
      i2c_write(AHT10_stream, AHT10_DATA1); 
      i2c_stop(AHT10_stream);
      
      i2c_start(AHT10_stream);          
      i2c_write(AHT10_stream, AHT10_I2CADDR << 1 | 0x01);  //Direccion de lectura   
      for(int8 i=0; i<=5; ++i)
      {
         buffer[i]=i2c_read(AHT10_stream);      
      }   
      i2c_stop(AHT10_stream);
   
      uint32_t hdata = buffer[1];
      hdata  <<= 8;
      hdata  |= buffer[2];
      hdata  <<= 4;
      hdata  |= buffer[3] >> 4;
      *hum = ((float)hdata * 100) / 0x100000;
      
      uint32_t tdata = buffer[3] & 0x0F;
      tdata <<= 8;
      tdata |= buffer[4];
      tdata <<= 8;
      tdata |= buffer[5];
      *temp = ((float)tdata * 200 / 0x100000) - 50;
   }
   while (buffer[0]==255);
}

